function dispchirp(start,chirp_len,freq,chirprate,fs)
% function dispchirp(start,chirp_len,freq,chirprate,fs)
% Generate the TF plot for chirps/chirplets given by the input data. 
%
%   input variables:
%
%   start       The start time points of the chirps/chirplets
%   chirp_len   The time duration of the chirps/chirplets
%   freq        The initial frequency of the chirps/chirplets
%   chirprate   The chirprate of the chirps/chirplets
%   fs          The sampling frequency. Used to reverse the normalisation
%               and generate the correct time and frequency axes in the
%               figure.
%
% Code written by Fabien Millioz and Mike Davies, last update 2016. This
% function is part of a software implementation of the Maximum Chirplet
% Transform and its application to the detection of piecewise linear chirp
% signals. Theory and details of the technique can be found in:
%
%   Millioz and Davies, "Sparse detection in the chirplet transform:
%   application to FMCW radar signals," IEEE Transactions on Sig. Proc. 
%   vol 60(6), pp 2800  2813, 2012.
%
% Please reference this paper in any publication that makes use of this
% software. Copyright 2016, University of Edinburgh.

freq=freq*fs; chirprate=chirprate*fs*fs; start=start/fs; chirp_len=chirp_len/fs;

for indtp=1:length(start)

  tmp=floor(rand*4);
  if tmp == 1; color='b'; end
  if tmp == 2; color='g'; end
  if tmp == 3; color='r'; end
  if tmp == 0; color='k'; end

  xs=[start(indtp) start(indtp)+chirp_len(indtp)];
  ys=[freq(indtp) freq(indtp)+chirprate(indtp)*chirp_len(indtp)];
  h=line(xs,ys);
  set(h,'Color',color)
end

axis([0 max(start+chirp_len) 0 fs])
